@@ -119,8 +119,11 @@ void console_print_size(off_t size, int tidx) {
 void console_print_stdout(char* s) {
   /* callback called from libsrcinst */
   status_pulse();  
-  console_print(s, TAG_STDOUT);
-  console_print("\n", TAG_NONE);
+
+  if (!state.o.quiet) {
+    console_print(s, TAG_STDOUT);
+    console_print("\n", TAG_NONE);
+  }
 }
 
 void console_print_stderr(char* s) {
