@@ -523,7 +523,8 @@ int dialog_input_package(char** filename, char** packagename) {
    Return 0 if the user cancelled the operation.
  */
 
-int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_list* s) {
+int dialog_configure(struct srcinst_configure_sets* opts, char **prefix,
+		     struct srcinst_string_list* s) {
   GtkWidget* dialog, *vbox, *notebook;
   GtkTooltips* tips;
   char* title = "Package Configuration";
@@ -537,7 +538,7 @@ int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_
     GtkWidget** check_buttons;
     GtkWidget** entries;
 
-  } columns[5];
+  } columns[6];
 
   dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(w_main[W_MAIN]),
 				       GTK_DIALOG_MODAL,
@@ -565,9 +566,10 @@ int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_
   columns[1].set = &(opts->packs); columns[1].title = "Packages";
   columns[2].set = &(opts->envs); columns[2].title = "Environment";
   columns[3].set = &(opts->olds); columns[3].title = "Features and Packages";
-  columns[4].set = &(opts->base); columns[4].title = "Directories";
+  columns[4].set = &(opts->res1); columns[4].title = "Uncategorized";
+  columns[5].set = &(opts->base); columns[5].title = "Directories";
 
-  for (i = 0; i < 5; i++) {
+  for (i = 0; i < 6; i++) {
     GtkWidget* vertical, *lbl, *scroll;
 
     if (columns[i].set->count == 0)
@@ -581,7 +583,7 @@ int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_
     scroll = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
 				   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-
+    
     lbl = gtk_label_new(columns[i].title);
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), scroll, lbl);
 
@@ -601,7 +603,13 @@ int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_
       gtk_box_pack_end(GTK_BOX(horizontal), columns[i].entries[j],
 		       FALSE, FALSE, 0);
 
-      gtk_entry_set_width_chars(GTK_ENTRY(columns[i].entries[j]), 10);
+      gtk_entry_set_width_chars(GTK_ENTRY(columns[i].entries[j]), 
+				i == 5 ? 20 : i == 2 ? 15 : 10);
+
+      if (i == 5 && j == 0 && state.o.prefix) {
+	/* pre set prefix option value */
+	gtk_entry_set_text(GTK_ENTRY(columns[i].entries[j]), state.o.prefix);
+      }
 
       gtk_box_pack_start(GTK_BOX(horizontal), columns[i].check_buttons[j],
 			 FALSE, FALSE, 0);
@@ -609,12 +617,6 @@ int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_
       label = gtk_label_new(columns[i].set->options[j].key);
       gtk_container_add(GTK_CONTAINER(columns[i].check_buttons[j]), label);
 
-      /*
-      text = srcinst_strjoin("<small>", columns[i].set->options[j].key,
-			     "</small>", 0);
-      gtk_label_set_markup(GTK_LABEL(label), text);
-      free(text);
-      */
       key = columns[i].set->options[j].key;
       param = columns[i].set->options[j].param;
       comment = columns[i].set->options[j].comment;
@@ -632,34 +634,46 @@ int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_
   gtk_widget_show_all(dialog);
   response = gtk_dialog_run(GTK_DIALOG(dialog));
 
-  for (i = 0; i < 5; i++) {
+  for (i = 0; i < 6; i++) {
     if (columns[i].set->count == 0)
       continue;
 
     for (j = 0; j < columns[i].set->count; j++) {
       if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(columns[i].check_buttons[j])) == TRUE) {
-	char* key; const char* value; char* string;
+
+	char* key; const char* value;
 	key = columns[i].set->options[j].key;
 	value = gtk_entry_get_text(GTK_ENTRY(columns[i].entries[j]));
 	
-	if (*value) {
-	  string = srcinst_strjoin(key, "=", value, 0);
+	if (i == 5 && j == 0) {
+	  /* prefix is handled specially */
+	  
+	  if (*value) 
+	    *prefix = srcinst_strdup(value);
+	  else
+	    *prefix = 0;
+	  
 	} else {
-	  string = srcinst_strdup(key);
-	}
+	  char *string;
+	  
+	  if (*value)
+	    string = srcinst_strjoin(key, "=", value, 0);
+	  else
+	    string = srcinst_strdup(key);
 				 
-	srcinst_add_string_list(s, string);
-	free(string);
+	  srcinst_add_string_list(s, string);
+	  free(string);
+	}
       }
     }
     
     free(columns[i].check_buttons);
     free(columns[i].entries);
   }
-
+  
   gtk_widget_destroy(dialog);
   gtk_object_destroy(GTK_OBJECT(tips));
-
+  
   return response == GTK_RESPONSE_OK;
 }
 
