@@ -35,7 +35,8 @@ char* dialog_input_opendir(char* title, char* startpath);
 int dialog_input_select_string(char* title, char* text, struct srcinst_string_list* s);
 int dialog_input_package(char** filename, char** packagename);
 int dialog_input_package2(char* title, char** filename, char** packagename);
-int dialog_configure(struct srcinst_configure_sets* opts, struct srcinst_string_list* s);
+int dialog_configure(struct srcinst_configure_sets* opts, char **prefix,
+		     struct srcinst_string_list* s);
 
 char* dialog_input_export_info(char* title, char* defaultname, SRCINST_EXPORT* fmt);
 
