@@ -93,11 +93,13 @@ void pref_create(void) {
   w_pref[W_PREF_SOURCE] = gtk_check_button_new_with_mnemonic("Install sou_rce");
   w_pref[W_PREF_CONFIGURE] = gtk_check_button_new_with_mnemonic("Show confi_guration");
   w_pref[W_PREF_STRIP] = gtk_check_button_new_with_mnemonic("Stri_p binaries (not recommended)");
+  w_pref[W_PREF_QUIET] = gtk_check_button_new_with_mnemonic("_Quiet");
 
   gtk_box_pack_start(GTK_BOX(vbox), w_pref[W_PREF_INSTALL], FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), w_pref[W_PREF_SOURCE], FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), w_pref[W_PREF_CONFIGURE], FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(vbox), w_pref[W_PREF_STRIP], FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), w_pref[W_PREF_QUIET], FALSE, FALSE, 0);
 
   /* Compression format */
   frame = gtk_frame_new(NULL);
@@ -155,10 +157,13 @@ void pref_reset(void) {
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w_pref[W_PREF_STRIP]),
 			       state.o.strip ? TRUE : FALSE);
 
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w_pref[W_PREF_QUIET]),
+			       state.o.quiet ? TRUE : FALSE);
+
   gtk_combo_box_set_active(GTK_COMBO_BOX(w_pref[W_PREF_COMP]),
 			   state.o.src_compress == SRCINST_COMP_Z ? 2 :
 			   state.o.src_compress == SRCINST_COMP_BZ2 ? 1 : 0);
-
+  
 }
 
 void pref_show(void) {
@@ -202,6 +207,7 @@ void pref_save_clicked(GtkWidget* unused_w, gpointer unused_data) {
   srcinst_set_pref_keep_source(state.o.source);
   srcinst_set_pref_manual_conf(state.o.manual_conf);
   srcinst_set_pref_strip(state.o.strip);
+  srcinst_set_pref_quiet(state.o.quiet);
   srcinst_set_pref_src_compress(state.o.src_compress);
 
   if (srcinst_save_pref()) {
@@ -255,6 +261,8 @@ void pref_apply_clicked(GtkWidget* unused_w, gpointer unused_data) {
 
   state.o.strip = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w_pref[W_PREF_STRIP])) == TRUE;
   
+  state.o.quiet = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w_pref[W_PREF_QUIET])) == TRUE;
+
   active = gtk_combo_box_get_active(GTK_COMBO_BOX(w_pref[W_PREF_COMP]));
   
   state.o.src_compress = 
