@@ -29,6 +29,7 @@
 #include "package_list.h"
 #include "greeting.h"
 #include "dialog.h"
+#include "action.h"
 
 #include "sourceinstall-gtk.h"
 
@@ -42,12 +43,17 @@ char* program_name;
 
 static void usage(void) {
   printf("GNU Source Installer GTK version " PACKAGE_VERSION " usage:\n\n");
-  printf("%s [ACTION]\n\n", program_name);
+  printf("%s [ACTION | FILENAME]\n\n", program_name);
   
   printf("ACTIONS\n");
   printf("-h, --help                 . show brief command line help\n");
-  printf("-V, --version              . show program version string\n\n");
-  printf("Run program without any ACTION arguments to start the GUI.\n");
+  printf("-V, --version              . show program version string\n");
+  printf("FILENAME\n");
+  printf("If none of the previous actions is specified, and a filename\n"
+	 "is given instead, run a package add action on FILENAME,\n"
+	 "assign default package name.\n\n");
+	 
+  printf("Run program without any arguments to start the GUI normally.\n");
   printf("Send bug reports to " PACKAGE_BUGREPORT " .\n");
 }
 
@@ -60,16 +66,28 @@ static void version(void) {
 
 int main(int argc, char* argv[]) {
   char* title = "main"; int i;
+  char* filename = 0;
 
   program_name = (argv[0] ? srcinst_basename(argv[0]) : "sourceinstall-gtk");
 
-  for (i = 1; i < argc; i++)
-    if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0)
-      { usage(); return 0; }
-    else if (strcmp(argv[i], "-V") == 0 || strcmp(argv[i], "--version") == 0)
-      { version(); return 0; }
-    else
-      { usage(); return 1; }
+  for (i = 1; i < argc; i++) {
+    if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0) {
+      usage();
+      return 0;
+
+    } else if (strcmp(argv[i], "-V") == 0 ||
+	       strcmp(argv[i], "--version") == 0) {
+      version();
+      return 0;
+
+    } else {
+      if (filename) {
+	usage();
+	return 1;
+      }
+      filename = argv[i];
+    }
+  }
 
   gtk_init(&argc, &argv);
   gui_splash();
@@ -87,6 +105,9 @@ int main(int argc, char* argv[]) {
   gui_show();
   greeting_show();
   
+  if (filename)
+    action_add(filename, 0);
+
   gtk_main();
   return 0;
 }
