@@ -40,9 +40,11 @@ void status_create(void) {
   /*
   gtk_progress_bar_set_pulse_step(bar, 0.05);
   */
-
   gtk_progress_bar_set_orientation(bar, GTK_PROGRESS_LEFT_TO_RIGHT);
+
+#if GTK_CHECK_VERSION(2, 6, 0)
   gtk_progress_bar_set_ellipsize(bar, PANGO_ELLIPSIZE_END);
+#endif  
 }
 
 void status_command(char* s) {
